Deprecated features
====================================================================================

fwdpy11 is under rapid development.  As such, API features may change from version to version. Where possible, we will
issue deprecation warnings and point you to the new API. However, Python suppresses deprecation warnings by default. To
see deprecation warnings, invoke python like this:

.. code-block:: bash

    python -Wd
